SetupError="SetupError"
DatabaseError="DatabaseError"
HTTPError="HTTPError"
FileError="FileError"
FolderError="FolderError"
TooManyRequests="TooManyRequests"
DataCreateError="DataCreateError"
DataUpdateError="DataUpdateError"

